# pyefun

为python提供强大且易用的中文函数库，完整的封装了易语言核心支持库所有功能，以及易语言中简单易用的函数

# 特性

- 完全兼容window linux mac运行
- 完全兼容python运行环境
- 全中文函数名和注释
- 封装了超100+命令
- 全部命令经过测试 100% 测试 放心使用
- 所有命令均有测试用例可以查看后立即使用
- 封装了超丰富的文本处理函数,简单,易用

# 安装


pip install pyefun

# 文档

https://pyefun.readthedocs.io/zh_CN/latest/?badge=latest